package org.jeecg.modules.demo.diccapital.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.diccapital.entity.DicCapital;
import org.jeecg.modules.demo.diccapital.service.IDicCapitalService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 首都
 * @Author: jeecg-boot
 * @Date:   2023-05-11
 * @Version: V1.0
 */
@Api(tags="首都")
@RestController
@RequestMapping("/diccapital/dicCapital")
@Slf4j
public class DicCapitalController extends JeecgController<DicCapital, IDicCapitalService> {
	@Autowired
	private IDicCapitalService dicCapitalService;
	
	/**
	 * 分页列表查询
	 *
	 * @param dicCapital
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "首都-分页列表查询")
	@ApiOperation(value="首都-分页列表查询", notes="首都-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<DicCapital>> queryPageList(DicCapital dicCapital,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<DicCapital> queryWrapper = QueryGenerator.initQueryWrapper(dicCapital, req.getParameterMap());
		Page<DicCapital> page = new Page<DicCapital>(pageNo, pageSize);
		IPage<DicCapital> pageList = dicCapitalService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param dicCapital
	 * @return
	 */
	@AutoLog(value = "首都-添加")
	@ApiOperation(value="首都-添加", notes="首都-添加")
	@RequiresPermissions("diccapital:dic_capital:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody DicCapital dicCapital) {
		dicCapitalService.save(dicCapital);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param dicCapital
	 * @return
	 */
	@AutoLog(value = "首都-编辑")
	@ApiOperation(value="首都-编辑", notes="首都-编辑")
	@RequiresPermissions("diccapital:dic_capital:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody DicCapital dicCapital) {
		dicCapitalService.updateById(dicCapital);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "首都-通过id删除")
	@ApiOperation(value="首都-通过id删除", notes="首都-通过id删除")
	@RequiresPermissions("diccapital:dic_capital:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		dicCapitalService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "首都-批量删除")
	@ApiOperation(value="首都-批量删除", notes="首都-批量删除")
	@RequiresPermissions("diccapital:dic_capital:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.dicCapitalService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "首都-通过id查询")
	@ApiOperation(value="首都-通过id查询", notes="首都-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<DicCapital> queryById(@RequestParam(name="id",required=true) String id) {
		DicCapital dicCapital = dicCapitalService.getById(id);
		if(dicCapital==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(dicCapital);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param dicCapital
    */
    @RequiresPermissions("diccapital:dic_capital:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, DicCapital dicCapital) {
        return super.exportXls(request, dicCapital, DicCapital.class, "首都");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("diccapital:dic_capital:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, DicCapital.class);
    }

}
