package org.jeecg.modules.demo.diccapitalerr.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.diccapitalerr.entity.DicCapitalErr;
import org.jeecg.modules.demo.diccapitalerr.service.IDicCapitalErrService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 首都错误类型
 * @Author: jeecg-boot
 * @Date:   2023-11-08
 * @Version: V1.0
 */
@Api(tags="首都错误类型")
@RestController
@RequestMapping("/diccapitalerr/dicCapitalErr")
@Slf4j
public class DicCapitalErrController extends JeecgController<DicCapitalErr, IDicCapitalErrService> {
	@Autowired
	private IDicCapitalErrService dicCapitalErrService;
	
	/**
	 * 分页列表查询
	 *
	 * @param dicCapitalErr
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "首都错误类型-分页列表查询")
	@ApiOperation(value="首都错误类型-分页列表查询", notes="首都错误类型-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<DicCapitalErr>> queryPageList(DicCapitalErr dicCapitalErr,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<DicCapitalErr> queryWrapper = QueryGenerator.initQueryWrapper(dicCapitalErr, req.getParameterMap());
		Page<DicCapitalErr> page = new Page<DicCapitalErr>(pageNo, pageSize);
		IPage<DicCapitalErr> pageList = dicCapitalErrService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param dicCapitalErr
	 * @return
	 */
	@AutoLog(value = "首都错误类型-添加")
	@ApiOperation(value="首都错误类型-添加", notes="首都错误类型-添加")
	@RequiresPermissions("diccapitalerr:dic_capital_err:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody DicCapitalErr dicCapitalErr) {
		dicCapitalErrService.save(dicCapitalErr);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param dicCapitalErr
	 * @return
	 */
	@AutoLog(value = "首都错误类型-编辑")
	@ApiOperation(value="首都错误类型-编辑", notes="首都错误类型-编辑")
	@RequiresPermissions("diccapitalerr:dic_capital_err:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody DicCapitalErr dicCapitalErr) {
		dicCapitalErrService.updateById(dicCapitalErr);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "首都错误类型-通过id删除")
	@ApiOperation(value="首都错误类型-通过id删除", notes="首都错误类型-通过id删除")
	@RequiresPermissions("diccapitalerr:dic_capital_err:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		dicCapitalErrService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "首都错误类型-批量删除")
	@ApiOperation(value="首都错误类型-批量删除", notes="首都错误类型-批量删除")
	@RequiresPermissions("diccapitalerr:dic_capital_err:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.dicCapitalErrService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "首都错误类型-通过id查询")
	@ApiOperation(value="首都错误类型-通过id查询", notes="首都错误类型-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<DicCapitalErr> queryById(@RequestParam(name="id",required=true) String id) {
		DicCapitalErr dicCapitalErr = dicCapitalErrService.getById(id);
		if(dicCapitalErr==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(dicCapitalErr);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param dicCapitalErr
    */
    @RequiresPermissions("diccapitalerr:dic_capital_err:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, DicCapitalErr dicCapitalErr) {
        return super.exportXls(request, dicCapitalErr, DicCapitalErr.class, "首都错误类型");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("diccapitalerr:dic_capital_err:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, DicCapitalErr.class);
    }

}
