package org.jeecg.modules.demo.homepageouterlink.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.homepageerrorlink.entity.HomePageErrorLink;
import org.jeecg.modules.demo.homepageouterlink.entity.HomePageOuterLink;
import org.jeecg.modules.demo.homepageouterlink.service.IHomePageOuterLinkService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 首页外链
 * @Author: jeecg-boot
 * @Date:   2023-11-22
 * @Version: V1.0
 */
@Api(tags="首页外链")
@RestController
@RequestMapping("/homepageouterlink/homePageOuterLink")
@Slf4j
public class HomePageOuterLinkController extends JeecgController<HomePageOuterLink, IHomePageOuterLinkService> {
	@Autowired
	private IHomePageOuterLinkService homePageOuterLinkService;
	
	/**
	 * 分页列表查询
	 *
	 * @param homePageOuterLink
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "首页外链-分页列表查询")
	@ApiOperation(value="首页外链-分页列表查询", notes="首页外链-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HomePageOuterLink>> queryPageList(HomePageOuterLink homePageOuterLink,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HomePageOuterLink> queryWrapper = QueryGenerator.initQueryWrapper(homePageOuterLink, req.getParameterMap());
		Page<HomePageOuterLink> page = new Page<HomePageOuterLink>(pageNo, pageSize);
		IPage<HomePageOuterLink> pageList = homePageOuterLinkService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	 @ApiOperation(value="首页错链-通过id查询", notes="首页错链-通过id查询")
	 @GetMapping(value = "/queryByIdErr")
	 public Result<HomePageOuterLink> queryByIdErr(@RequestParam(name="id",required=true) String id) {
		 HomePageOuterLink homePageOuterLink = homePageOuterLinkService.getById(id);
		 try {
			 List<String> AurlList = new ArrayList<String>();
			 List<String> BurlList = new ArrayList<String>();
			 List<String> urlList = new ArrayList<String>();
			 String strList = homePageOuterLink.getStrList();
			 String[] split = strList.split(",");
			 int i = 0 ;
			 for (String s : split) {
				 if(!ObjectUtils.isEmpty(s) && !s.equals("stylesheet")){
					 AurlList.add("<a href='#Amao"+i+"'>"+s+"</a>");
					 BurlList.add("<a href='#Bmao"+i+"'>"+s+"</a>");
					 urlList.add(s);
					 i++;
				 }
			 }
			 homePageOuterLink.setUrlList(urlList);
			 homePageOuterLink.setAurlList(AurlList);
			 homePageOuterLink.setBurlList(BurlList);
		 }catch (Exception e){
			 e.printStackTrace();
		 }
		 if(homePageOuterLink==null) {
			 return Result.error("未找到对应数据");
		 }
		 return Result.OK(homePageOuterLink);
	 }




	 /**
	 *   添加
	 *
	 * @param homePageOuterLink
	 * @return
	 */
	@AutoLog(value = "首页外链-添加")
	@ApiOperation(value="首页外链-添加", notes="首页外链-添加")
	@RequiresPermissions("homepageouterlink:home_page_outer_link:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HomePageOuterLink homePageOuterLink) {
		homePageOuterLinkService.save(homePageOuterLink);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param homePageOuterLink
	 * @return
	 */
	@AutoLog(value = "首页外链-编辑")
	@ApiOperation(value="首页外链-编辑", notes="首页外链-编辑")
	@RequiresPermissions("homepageouterlink:home_page_outer_link:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HomePageOuterLink homePageOuterLink) {
		homePageOuterLinkService.updateById(homePageOuterLink);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "首页外链-通过id删除")
	@ApiOperation(value="首页外链-通过id删除", notes="首页外链-通过id删除")
	@RequiresPermissions("homepageouterlink:home_page_outer_link:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		homePageOuterLinkService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "首页外链-批量删除")
	@ApiOperation(value="首页外链-批量删除", notes="首页外链-批量删除")
	@RequiresPermissions("homepageouterlink:home_page_outer_link:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.homePageOuterLinkService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "首页外链-通过id查询")
	@ApiOperation(value="首页外链-通过id查询", notes="首页外链-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HomePageOuterLink> queryById(@RequestParam(name="id",required=true) String id) {
		HomePageOuterLink homePageOuterLink = homePageOuterLinkService.getById(id);
		if(homePageOuterLink==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(homePageOuterLink);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param homePageOuterLink
    */
    @RequiresPermissions("homepageouterlink:home_page_outer_link:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HomePageOuterLink homePageOuterLink) {
        return super.exportXls(request, homePageOuterLink, HomePageOuterLink.class, "首页外链");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("homepageouterlink:home_page_outer_link:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HomePageOuterLink.class);
    }

}
