package org.jeecg.modules.demo.linkcaptureerrormessage.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkcaptureerrormessage.entity.LinkCaptureErrorMessage;
import org.jeecg.modules.demo.linkcaptureerrormessage.service.ILinkCaptureErrorMessageService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 错敏词信息
 * @Author: jeecg-boot
 * @Date:   2023-04-12
 * @Version: V1.0
 */
@Api(tags="错敏词信息")
@RestController
@RequestMapping("/linkcaptureerrormessage/linkCaptureErrorMessage")
@Slf4j
public class LinkCaptureErrorMessageController extends JeecgController<LinkCaptureErrorMessage, ILinkCaptureErrorMessageService> {
	@Autowired
	private ILinkCaptureErrorMessageService linkCaptureErrorMessageService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkCaptureErrorMessage
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "错敏词信息-分页列表查询")
	@ApiOperation(value="错敏词信息-分页列表查询", notes="错敏词信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkCaptureErrorMessage>> queryPageList(LinkCaptureErrorMessage linkCaptureErrorMessage,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkCaptureErrorMessage> queryWrapper = QueryGenerator.initQueryWrapper(linkCaptureErrorMessage, req.getParameterMap());

		queryWrapper.groupBy("errer_word");
		Page<LinkCaptureErrorMessage> page = new Page<LinkCaptureErrorMessage>(pageNo, pageSize);
		IPage<LinkCaptureErrorMessage> pageList = linkCaptureErrorMessageService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkCaptureErrorMessage
	 * @return
	 */
	@AutoLog(value = "错敏词信息-添加")
	@ApiOperation(value="错敏词信息-添加", notes="错敏词信息-添加")
	@RequiresPermissions("linkcaptureerrormessage:link_capture_error_message:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkCaptureErrorMessage linkCaptureErrorMessage) {
		linkCaptureErrorMessageService.save(linkCaptureErrorMessage);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkCaptureErrorMessage
	 * @return
	 */
	@AutoLog(value = "错敏词信息-编辑")
	@ApiOperation(value="错敏词信息-编辑", notes="错敏词信息-编辑")
	@RequiresPermissions("linkcaptureerrormessage:link_capture_error_message:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkCaptureErrorMessage linkCaptureErrorMessage) {
		linkCaptureErrorMessageService.updateById(linkCaptureErrorMessage);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "错敏词信息-通过id删除")
	@ApiOperation(value="错敏词信息-通过id删除", notes="错敏词信息-通过id删除")
	@RequiresPermissions("linkcaptureerrormessage:link_capture_error_message:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkCaptureErrorMessageService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "错敏词信息-批量删除")
	@ApiOperation(value="错敏词信息-批量删除", notes="错敏词信息-批量删除")
	@RequiresPermissions("linkcaptureerrormessage:link_capture_error_message:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkCaptureErrorMessageService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "错敏词信息-通过id查询")
	@ApiOperation(value="错敏词信息-通过id查询", notes="错敏词信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkCaptureErrorMessage> queryById(@RequestParam(name="id",required=true) String id) {
		LinkCaptureErrorMessage linkCaptureErrorMessage = linkCaptureErrorMessageService.getById(id);
		if(linkCaptureErrorMessage==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkCaptureErrorMessage);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkCaptureErrorMessage
    */
    @RequiresPermissions("linkcaptureerrormessage:link_capture_error_message:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkCaptureErrorMessage linkCaptureErrorMessage) {
        return super.exportXls(request, linkCaptureErrorMessage, LinkCaptureErrorMessage.class, "错敏词信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkcaptureerrormessage:link_capture_error_message:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkCaptureErrorMessage.class);
    }

}
