package org.jeecg.modules.demo.linkerrorwordstatistics.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkerrorwordstatistics.entity.LinkErrorWordStatistics;
import org.jeecg.modules.demo.linkerrorwordstatistics.service.ILinkErrorWordStatisticsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.demo.mainsite.entity.MainSite;
import org.jeecg.modules.demo.mainsite.service.IMainSiteService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 错敏词信息统计
 * @Author: jeecg-boot
 * @Date:   2023-04-12
 * @Version: V1.0
 */
@Api(tags="错敏词信息统计")
@RestController
@RequestMapping("/linkerrorwordstatistics/linkErrorWordStatistics")
@Slf4j
public class LinkErrorWordStatisticsController extends JeecgController<LinkErrorWordStatistics, ILinkErrorWordStatisticsService> {
	@Autowired
	private ILinkErrorWordStatisticsService linkErrorWordStatisticsService;
	 @Autowired
	 private IMainSiteService iMainSiteService;
	/**
	 * 分页列表查询
	 *
	 * @param linkErrorWordStatistics
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "错敏词信息统计-分页列表查询")
	@ApiOperation(value="错敏词信息统计-分页列表查询", notes="错敏词信息统计-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkErrorWordStatistics>> queryPageList(LinkErrorWordStatistics linkErrorWordStatistics,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkErrorWordStatistics> queryWrapper = QueryGenerator.initQueryWrapper(linkErrorWordStatistics, req.getParameterMap());
		Page<LinkErrorWordStatistics> page = new Page<LinkErrorWordStatistics>(pageNo, pageSize);
		IPage<LinkErrorWordStatistics> pageList = linkErrorWordStatisticsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkErrorWordStatistics
	 * @return
	 */
	@AutoLog(value = "错敏词信息统计-添加")
	@ApiOperation(value="错敏词信息统计-添加", notes="错敏词信息统计-添加")
	@RequiresPermissions("linkerrorwordstatistics:link_error_word_statistics:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkErrorWordStatistics linkErrorWordStatistics) {
		try {
			String mainSiteId = linkErrorWordStatistics.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkErrorWordStatistics.setMainSiteName(mainSite.getMainSiteName());
			linkErrorWordStatistics.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkErrorWordStatisticsService.save(linkErrorWordStatistics);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkErrorWordStatistics
	 * @return
	 */
	@AutoLog(value = "错敏词信息统计-编辑")
	@ApiOperation(value="错敏词信息统计-编辑", notes="错敏词信息统计-编辑")
	@RequiresPermissions("linkerrorwordstatistics:link_error_word_statistics:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkErrorWordStatistics linkErrorWordStatistics) {
		try {
			String mainSiteId = linkErrorWordStatistics.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkErrorWordStatistics.setMainSiteName(mainSite.getMainSiteName());
			linkErrorWordStatistics.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkErrorWordStatisticsService.updateById(linkErrorWordStatistics);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "错敏词信息统计-通过id删除")
	@ApiOperation(value="错敏词信息统计-通过id删除", notes="错敏词信息统计-通过id删除")
	@RequiresPermissions("linkerrorwordstatistics:link_error_word_statistics:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkErrorWordStatisticsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "错敏词信息统计-批量删除")
	@ApiOperation(value="错敏词信息统计-批量删除", notes="错敏词信息统计-批量删除")
	@RequiresPermissions("linkerrorwordstatistics:link_error_word_statistics:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkErrorWordStatisticsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "错敏词信息统计-通过id查询")
	@ApiOperation(value="错敏词信息统计-通过id查询", notes="错敏词信息统计-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkErrorWordStatistics> queryById(@RequestParam(name="id",required=true) String id) {
		LinkErrorWordStatistics linkErrorWordStatistics = linkErrorWordStatisticsService.getById(id);
		if(linkErrorWordStatistics==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkErrorWordStatistics);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkErrorWordStatistics
    */
    @RequiresPermissions("linkerrorwordstatistics:link_error_word_statistics:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkErrorWordStatistics linkErrorWordStatistics) {
        return super.exportXls(request, linkErrorWordStatistics, LinkErrorWordStatistics.class, "错敏词信息统计");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkerrorwordstatistics:link_error_word_statistics:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkErrorWordStatistics.class);
    }

}
