package org.jeecg.modules.demo.linkouterouterstatistics.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkouterouterstatistics.entity.LinkOuterouterStatistics;
import org.jeecg.modules.demo.linkouterouterstatistics.service.ILinkOuterouterStatisticsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.demo.mainsite.entity.MainSite;
import org.jeecg.modules.demo.mainsite.service.IMainSiteService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 外链信息统计
 * @Author: jeecg-boot
 * @Date:   2023-04-13
 * @Version: V1.0
 */
@Api(tags="外链信息统计")
@RestController
@RequestMapping("/linkouterouterstatistics/linkOuterouterStatistics")
@Slf4j
public class LinkOuterouterStatisticsController extends JeecgController<LinkOuterouterStatistics, ILinkOuterouterStatisticsService> {
	@Autowired
	private ILinkOuterouterStatisticsService linkOuterouterStatisticsService;
	 @Autowired
	 private IMainSiteService iMainSiteService;
	/**
	 * 分页列表查询
	 *
	 * @param linkOuterouterStatistics
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "外链信息统计-分页列表查询")
	@ApiOperation(value="外链信息统计-分页列表查询", notes="外链信息统计-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkOuterouterStatistics>> queryPageList(LinkOuterouterStatistics linkOuterouterStatistics,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkOuterouterStatistics> queryWrapper = QueryGenerator.initQueryWrapper(linkOuterouterStatistics, req.getParameterMap());
		Page<LinkOuterouterStatistics> page = new Page<LinkOuterouterStatistics>(pageNo, pageSize);
		IPage<LinkOuterouterStatistics> pageList = linkOuterouterStatisticsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkOuterouterStatistics
	 * @return
	 */
	@AutoLog(value = "外链信息统计-添加")
	@ApiOperation(value="外链信息统计-添加", notes="外链信息统计-添加")
	@RequiresPermissions("linkouterouterstatistics:link_outerouter_statistics:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkOuterouterStatistics linkOuterouterStatistics) {

		try {
			String mainSiteId = linkOuterouterStatistics.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkOuterouterStatistics.setMainSiteName(mainSite.getMainSiteName());
			linkOuterouterStatistics.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}

		linkOuterouterStatisticsService.save(linkOuterouterStatistics);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkOuterouterStatistics
	 * @return
	 */
	@AutoLog(value = "外链信息统计-编辑")
	@ApiOperation(value="外链信息统计-编辑", notes="外链信息统计-编辑")
	@RequiresPermissions("linkouterouterstatistics:link_outerouter_statistics:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkOuterouterStatistics linkOuterouterStatistics) {
		try {
			String mainSiteId = linkOuterouterStatistics.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkOuterouterStatistics.setMainSiteName(mainSite.getMainSiteName());
			linkOuterouterStatistics.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}
		linkOuterouterStatisticsService.updateById(linkOuterouterStatistics);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "外链信息统计-通过id删除")
	@ApiOperation(value="外链信息统计-通过id删除", notes="外链信息统计-通过id删除")
	@RequiresPermissions("linkouterouterstatistics:link_outerouter_statistics:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkOuterouterStatisticsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "外链信息统计-批量删除")
	@ApiOperation(value="外链信息统计-批量删除", notes="外链信息统计-批量删除")
	@RequiresPermissions("linkouterouterstatistics:link_outerouter_statistics:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkOuterouterStatisticsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "外链信息统计-通过id查询")
	@ApiOperation(value="外链信息统计-通过id查询", notes="外链信息统计-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkOuterouterStatistics> queryById(@RequestParam(name="id",required=true) String id) {
		LinkOuterouterStatistics linkOuterouterStatistics = linkOuterouterStatisticsService.getById(id);
		if(linkOuterouterStatistics==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkOuterouterStatistics);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkOuterouterStatistics
    */
    @RequiresPermissions("linkouterouterstatistics:link_outerouter_statistics:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkOuterouterStatistics linkOuterouterStatistics) {
        return super.exportXls(request, linkOuterouterStatistics, LinkOuterouterStatistics.class, "外链信息统计");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkouterouterstatistics:link_outerouter_statistics:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkOuterouterStatistics.class);
    }

}
