package org.jeecg.modules.demo.linkpublishingmainbody.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkpublishingmainbody.entity.LinkPublishingMainBody;
import org.jeecg.modules.demo.linkpublishingmainbody.service.ILinkPublishingMainBodyService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.demo.mainsite.entity.MainSite;
import org.jeecg.modules.demo.mainsite.service.IMainSiteService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 文章内容元素抓取定位
 * @Author: jeecg-boot
 * @Date:   2023-11-09
 * @Version: V1.0
 */
@Api(tags="文章内容元素抓取定位")
@RestController
@RequestMapping("/linkpublishingmainbody/linkPublishingMainBody")
@Slf4j
public class LinkPublishingMainBodyController extends JeecgController<LinkPublishingMainBody, ILinkPublishingMainBodyService> {
	@Autowired
	private ILinkPublishingMainBodyService linkPublishingMainBodyService;

	 @Autowired
	 private IMainSiteService iMainSiteService;
	/**
	 * 分页列表查询
	 *
	 * @param linkPublishingMainBody
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "文章内容元素抓取定位-分页列表查询")
	@ApiOperation(value="文章内容元素抓取定位-分页列表查询", notes="文章内容元素抓取定位-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkPublishingMainBody>> queryPageList(LinkPublishingMainBody linkPublishingMainBody,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkPublishingMainBody> queryWrapper = QueryGenerator.initQueryWrapper(linkPublishingMainBody, req.getParameterMap());
		Page<LinkPublishingMainBody> page = new Page<LinkPublishingMainBody>(pageNo, pageSize);
		IPage<LinkPublishingMainBody> pageList = linkPublishingMainBodyService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkPublishingMainBody
	 * @return
	 */
	@AutoLog(value = "文章内容元素抓取定位-添加")
	@ApiOperation(value="文章内容元素抓取定位-添加", notes="文章内容元素抓取定位-添加")
	@RequiresPermissions("linkpublishingmainbody:link_publishing_main_body:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkPublishingMainBody linkPublishingMainBody) {

		try {
			String mainSiteId = linkPublishingMainBody.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkPublishingMainBody.setMainSiteName(mainSite.getMainSiteName());
			linkPublishingMainBody.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}

		linkPublishingMainBodyService.save(linkPublishingMainBody);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkPublishingMainBody
	 * @return
	 */
	@AutoLog(value = "文章内容元素抓取定位-编辑")
	@ApiOperation(value="文章内容元素抓取定位-编辑", notes="文章内容元素抓取定位-编辑")
	@RequiresPermissions("linkpublishingmainbody:link_publishing_main_body:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkPublishingMainBody linkPublishingMainBody) {

		try {
			String mainSiteId = linkPublishingMainBody.getMainSiteId();
			MainSite mainSite = iMainSiteService.getById(mainSiteId);
			linkPublishingMainBody.setMainSiteName(mainSite.getMainSiteName());
			linkPublishingMainBody.setMainSiteUrl(mainSite.getMainSiteUrl());
		}catch (Exception e){
			e.printStackTrace();
		}


		linkPublishingMainBodyService.updateById(linkPublishingMainBody);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "文章内容元素抓取定位-通过id删除")
	@ApiOperation(value="文章内容元素抓取定位-通过id删除", notes="文章内容元素抓取定位-通过id删除")
	@RequiresPermissions("linkpublishingmainbody:link_publishing_main_body:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkPublishingMainBodyService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "文章内容元素抓取定位-批量删除")
	@ApiOperation(value="文章内容元素抓取定位-批量删除", notes="文章内容元素抓取定位-批量删除")
	@RequiresPermissions("linkpublishingmainbody:link_publishing_main_body:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkPublishingMainBodyService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "文章内容元素抓取定位-通过id查询")
	@ApiOperation(value="文章内容元素抓取定位-通过id查询", notes="文章内容元素抓取定位-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkPublishingMainBody> queryById(@RequestParam(name="id",required=true) String id) {
		LinkPublishingMainBody linkPublishingMainBody = linkPublishingMainBodyService.getById(id);
		if(linkPublishingMainBody==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkPublishingMainBody);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkPublishingMainBody
    */
    @RequiresPermissions("linkpublishingmainbody:link_publishing_main_body:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkPublishingMainBody linkPublishingMainBody) {
        return super.exportXls(request, linkPublishingMainBody, LinkPublishingMainBody.class, "文章内容元素抓取定位");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkpublishingmainbody:link_publishing_main_body:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkPublishingMainBody.class);
    }

}
