package org.jeecg.modules.demo.linkwechatbankcarddetectionlog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwechatbankcarddetectionlog.entity.LinkWechatBankCardDetectionLog;
import org.jeecg.modules.demo.linkwechatbankcarddetectionlog.service.ILinkWechatBankCardDetectionLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信银行卡号检测日志
 * @Author: jeecg-boot
 * @Date:   2023-07-03
 * @Version: V1.0
 */
@Api(tags="微信银行卡号检测日志")
@RestController
@RequestMapping("/linkwechatbankcarddetectionlog/linkWechatBankCardDetectionLog")
@Slf4j
public class LinkWechatBankCardDetectionLogController extends JeecgController<LinkWechatBankCardDetectionLog, ILinkWechatBankCardDetectionLogService> {
	@Autowired
	private ILinkWechatBankCardDetectionLogService linkWechatBankCardDetectionLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWechatBankCardDetectionLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信银行卡号检测日志-分页列表查询")
	@ApiOperation(value="微信银行卡号检测日志-分页列表查询", notes="微信银行卡号检测日志-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWechatBankCardDetectionLog>> queryPageList(LinkWechatBankCardDetectionLog linkWechatBankCardDetectionLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWechatBankCardDetectionLog> queryWrapper = QueryGenerator.initQueryWrapper(linkWechatBankCardDetectionLog, req.getParameterMap());
		Page<LinkWechatBankCardDetectionLog> page = new Page<LinkWechatBankCardDetectionLog>(pageNo, pageSize);
		IPage<LinkWechatBankCardDetectionLog> pageList = linkWechatBankCardDetectionLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWechatBankCardDetectionLog
	 * @return
	 */
	@AutoLog(value = "微信银行卡号检测日志-添加")
	@ApiOperation(value="微信银行卡号检测日志-添加", notes="微信银行卡号检测日志-添加")
	@RequiresPermissions("linkwechatbankcarddetectionlog:link_wechat_bank_card_detection_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWechatBankCardDetectionLog linkWechatBankCardDetectionLog) {
		linkWechatBankCardDetectionLogService.save(linkWechatBankCardDetectionLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWechatBankCardDetectionLog
	 * @return
	 */
	@AutoLog(value = "微信银行卡号检测日志-编辑")
	@ApiOperation(value="微信银行卡号检测日志-编辑", notes="微信银行卡号检测日志-编辑")
	@RequiresPermissions("linkwechatbankcarddetectionlog:link_wechat_bank_card_detection_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWechatBankCardDetectionLog linkWechatBankCardDetectionLog) {
		linkWechatBankCardDetectionLogService.updateById(linkWechatBankCardDetectionLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信银行卡号检测日志-通过id删除")
	@ApiOperation(value="微信银行卡号检测日志-通过id删除", notes="微信银行卡号检测日志-通过id删除")
	@RequiresPermissions("linkwechatbankcarddetectionlog:link_wechat_bank_card_detection_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWechatBankCardDetectionLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信银行卡号检测日志-批量删除")
	@ApiOperation(value="微信银行卡号检测日志-批量删除", notes="微信银行卡号检测日志-批量删除")
	@RequiresPermissions("linkwechatbankcarddetectionlog:link_wechat_bank_card_detection_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWechatBankCardDetectionLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信银行卡号检测日志-通过id查询")
	@ApiOperation(value="微信银行卡号检测日志-通过id查询", notes="微信银行卡号检测日志-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWechatBankCardDetectionLog> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWechatBankCardDetectionLog linkWechatBankCardDetectionLog = linkWechatBankCardDetectionLogService.getById(id);
		if(linkWechatBankCardDetectionLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWechatBankCardDetectionLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWechatBankCardDetectionLog
    */
    @RequiresPermissions("linkwechatbankcarddetectionlog:link_wechat_bank_card_detection_log:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWechatBankCardDetectionLog linkWechatBankCardDetectionLog) {
        return super.exportXls(request, linkWechatBankCardDetectionLog, LinkWechatBankCardDetectionLog.class, "微信银行卡号检测日志");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwechatbankcarddetectionlog:link_wechat_bank_card_detection_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWechatBankCardDetectionLog.class);
    }

}
