package org.jeecg.modules.demo.linkwechatpersonaliddetectionstatistics.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwechatpersonaliddetectionstatistics.entity.LinkWechatPersonalIdDetectionStatistics;
import org.jeecg.modules.demo.linkwechatpersonaliddetectionstatistics.service.ILinkWechatPersonalIdDetectionStatisticsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信身份证统计信息
 * @Author: jeecg-boot
 * @Date:   2023-07-03
 * @Version: V1.0
 */
@Api(tags="微信身份证统计信息")
@RestController
@RequestMapping("/linkwechatpersonaliddetectionstatistics/linkWechatPersonalIdDetectionStatistics")
@Slf4j
public class LinkWechatPersonalIdDetectionStatisticsController extends JeecgController<LinkWechatPersonalIdDetectionStatistics, ILinkWechatPersonalIdDetectionStatisticsService> {
	@Autowired
	private ILinkWechatPersonalIdDetectionStatisticsService linkWechatPersonalIdDetectionStatisticsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWechatPersonalIdDetectionStatistics
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信身份证统计信息-分页列表查询")
	@ApiOperation(value="微信身份证统计信息-分页列表查询", notes="微信身份证统计信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWechatPersonalIdDetectionStatistics>> queryPageList(LinkWechatPersonalIdDetectionStatistics linkWechatPersonalIdDetectionStatistics,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWechatPersonalIdDetectionStatistics> queryWrapper = QueryGenerator.initQueryWrapper(linkWechatPersonalIdDetectionStatistics, req.getParameterMap());
		Page<LinkWechatPersonalIdDetectionStatistics> page = new Page<LinkWechatPersonalIdDetectionStatistics>(pageNo, pageSize);
		IPage<LinkWechatPersonalIdDetectionStatistics> pageList = linkWechatPersonalIdDetectionStatisticsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWechatPersonalIdDetectionStatistics
	 * @return
	 */
	@AutoLog(value = "微信身份证统计信息-添加")
	@ApiOperation(value="微信身份证统计信息-添加", notes="微信身份证统计信息-添加")
	@RequiresPermissions("linkwechatpersonaliddetectionstatistics:link_wechat_personal_id_detection_statistics:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWechatPersonalIdDetectionStatistics linkWechatPersonalIdDetectionStatistics) {
		linkWechatPersonalIdDetectionStatisticsService.save(linkWechatPersonalIdDetectionStatistics);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWechatPersonalIdDetectionStatistics
	 * @return
	 */
	@AutoLog(value = "微信身份证统计信息-编辑")
	@ApiOperation(value="微信身份证统计信息-编辑", notes="微信身份证统计信息-编辑")
	@RequiresPermissions("linkwechatpersonaliddetectionstatistics:link_wechat_personal_id_detection_statistics:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWechatPersonalIdDetectionStatistics linkWechatPersonalIdDetectionStatistics) {
		linkWechatPersonalIdDetectionStatisticsService.updateById(linkWechatPersonalIdDetectionStatistics);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信身份证统计信息-通过id删除")
	@ApiOperation(value="微信身份证统计信息-通过id删除", notes="微信身份证统计信息-通过id删除")
	@RequiresPermissions("linkwechatpersonaliddetectionstatistics:link_wechat_personal_id_detection_statistics:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWechatPersonalIdDetectionStatisticsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信身份证统计信息-批量删除")
	@ApiOperation(value="微信身份证统计信息-批量删除", notes="微信身份证统计信息-批量删除")
	@RequiresPermissions("linkwechatpersonaliddetectionstatistics:link_wechat_personal_id_detection_statistics:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWechatPersonalIdDetectionStatisticsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信身份证统计信息-通过id查询")
	@ApiOperation(value="微信身份证统计信息-通过id查询", notes="微信身份证统计信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWechatPersonalIdDetectionStatistics> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWechatPersonalIdDetectionStatistics linkWechatPersonalIdDetectionStatistics = linkWechatPersonalIdDetectionStatisticsService.getById(id);
		if(linkWechatPersonalIdDetectionStatistics==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWechatPersonalIdDetectionStatistics);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWechatPersonalIdDetectionStatistics
    */
    @RequiresPermissions("linkwechatpersonaliddetectionstatistics:link_wechat_personal_id_detection_statistics:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWechatPersonalIdDetectionStatistics linkWechatPersonalIdDetectionStatistics) {
        return super.exportXls(request, linkWechatPersonalIdDetectionStatistics, LinkWechatPersonalIdDetectionStatistics.class, "微信身份证统计信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwechatpersonaliddetectionstatistics:link_wechat_personal_id_detection_statistics:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWechatPersonalIdDetectionStatistics.class);
    }

}
