package org.jeecg.modules.demo.linkwechatphonedetectionlog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwechatphonedetectionlog.entity.LinkWechatPhoneDetectionLog;
import org.jeecg.modules.demo.linkwechatphonedetectionlog.service.ILinkWechatPhoneDetectionLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信手机号检测日志信息
 * @Author: jeecg-boot
 * @Date:   2023-07-03
 * @Version: V1.0
 */
@Api(tags="微信手机号检测日志信息")
@RestController
@RequestMapping("/linkwechatphonedetectionlog/linkWechatPhoneDetectionLog")
@Slf4j
public class LinkWechatPhoneDetectionLogController extends JeecgController<LinkWechatPhoneDetectionLog, ILinkWechatPhoneDetectionLogService> {
	@Autowired
	private ILinkWechatPhoneDetectionLogService linkWechatPhoneDetectionLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWechatPhoneDetectionLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信手机号检测日志信息-分页列表查询")
	@ApiOperation(value="微信手机号检测日志信息-分页列表查询", notes="微信手机号检测日志信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWechatPhoneDetectionLog>> queryPageList(LinkWechatPhoneDetectionLog linkWechatPhoneDetectionLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWechatPhoneDetectionLog> queryWrapper = QueryGenerator.initQueryWrapper(linkWechatPhoneDetectionLog, req.getParameterMap());
		Page<LinkWechatPhoneDetectionLog> page = new Page<LinkWechatPhoneDetectionLog>(pageNo, pageSize);
		IPage<LinkWechatPhoneDetectionLog> pageList = linkWechatPhoneDetectionLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWechatPhoneDetectionLog
	 * @return
	 */
	@AutoLog(value = "微信手机号检测日志信息-添加")
	@ApiOperation(value="微信手机号检测日志信息-添加", notes="微信手机号检测日志信息-添加")
	@RequiresPermissions("linkwechatphonedetectionlog:link_wechat_phone_detection_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWechatPhoneDetectionLog linkWechatPhoneDetectionLog) {
		linkWechatPhoneDetectionLogService.save(linkWechatPhoneDetectionLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWechatPhoneDetectionLog
	 * @return
	 */
	@AutoLog(value = "微信手机号检测日志信息-编辑")
	@ApiOperation(value="微信手机号检测日志信息-编辑", notes="微信手机号检测日志信息-编辑")
	@RequiresPermissions("linkwechatphonedetectionlog:link_wechat_phone_detection_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWechatPhoneDetectionLog linkWechatPhoneDetectionLog) {
		linkWechatPhoneDetectionLogService.updateById(linkWechatPhoneDetectionLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信手机号检测日志信息-通过id删除")
	@ApiOperation(value="微信手机号检测日志信息-通过id删除", notes="微信手机号检测日志信息-通过id删除")
	@RequiresPermissions("linkwechatphonedetectionlog:link_wechat_phone_detection_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWechatPhoneDetectionLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信手机号检测日志信息-批量删除")
	@ApiOperation(value="微信手机号检测日志信息-批量删除", notes="微信手机号检测日志信息-批量删除")
	@RequiresPermissions("linkwechatphonedetectionlog:link_wechat_phone_detection_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWechatPhoneDetectionLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信手机号检测日志信息-通过id查询")
	@ApiOperation(value="微信手机号检测日志信息-通过id查询", notes="微信手机号检测日志信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWechatPhoneDetectionLog> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWechatPhoneDetectionLog linkWechatPhoneDetectionLog = linkWechatPhoneDetectionLogService.getById(id);
		if(linkWechatPhoneDetectionLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWechatPhoneDetectionLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWechatPhoneDetectionLog
    */
    @RequiresPermissions("linkwechatphonedetectionlog:link_wechat_phone_detection_log:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWechatPhoneDetectionLog linkWechatPhoneDetectionLog) {
        return super.exportXls(request, linkWechatPhoneDetectionLog, LinkWechatPhoneDetectionLog.class, "微信手机号检测日志信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwechatphonedetectionlog:link_wechat_phone_detection_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWechatPhoneDetectionLog.class);
    }

}
