package org.jeecg.modules.demo.linkwechatphonedetectionstatistics.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.linkwechatphonedetectionstatistics.entity.LinkWechatPhoneDetectionStatistics;
import org.jeecg.modules.demo.linkwechatphonedetectionstatistics.service.ILinkWechatPhoneDetectionStatisticsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信手机号统计信息
 * @Author: jeecg-boot
 * @Date:   2023-07-05
 * @Version: V1.0
 */
@Api(tags="微信手机号统计信息")
@RestController
@RequestMapping("/linkwechatphonedetectionstatistics/linkWechatPhoneDetectionStatistics")
@Slf4j
public class LinkWechatPhoneDetectionStatisticsController extends JeecgController<LinkWechatPhoneDetectionStatistics, ILinkWechatPhoneDetectionStatisticsService> {
	@Autowired
	private ILinkWechatPhoneDetectionStatisticsService linkWechatPhoneDetectionStatisticsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param linkWechatPhoneDetectionStatistics
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信手机号统计信息-分页列表查询")
	@ApiOperation(value="微信手机号统计信息-分页列表查询", notes="微信手机号统计信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<LinkWechatPhoneDetectionStatistics>> queryPageList(LinkWechatPhoneDetectionStatistics linkWechatPhoneDetectionStatistics,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<LinkWechatPhoneDetectionStatistics> queryWrapper = QueryGenerator.initQueryWrapper(linkWechatPhoneDetectionStatistics, req.getParameterMap());
		Page<LinkWechatPhoneDetectionStatistics> page = new Page<LinkWechatPhoneDetectionStatistics>(pageNo, pageSize);
		IPage<LinkWechatPhoneDetectionStatistics> pageList = linkWechatPhoneDetectionStatisticsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param linkWechatPhoneDetectionStatistics
	 * @return
	 */
	@AutoLog(value = "微信手机号统计信息-添加")
	@ApiOperation(value="微信手机号统计信息-添加", notes="微信手机号统计信息-添加")
	@RequiresPermissions("linkwechatphonedetectionstatistics:link_wechat_phone_detection_statistics:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody LinkWechatPhoneDetectionStatistics linkWechatPhoneDetectionStatistics) {
		linkWechatPhoneDetectionStatisticsService.save(linkWechatPhoneDetectionStatistics);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param linkWechatPhoneDetectionStatistics
	 * @return
	 */
	@AutoLog(value = "微信手机号统计信息-编辑")
	@ApiOperation(value="微信手机号统计信息-编辑", notes="微信手机号统计信息-编辑")
	@RequiresPermissions("linkwechatphonedetectionstatistics:link_wechat_phone_detection_statistics:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody LinkWechatPhoneDetectionStatistics linkWechatPhoneDetectionStatistics) {
		linkWechatPhoneDetectionStatisticsService.updateById(linkWechatPhoneDetectionStatistics);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信手机号统计信息-通过id删除")
	@ApiOperation(value="微信手机号统计信息-通过id删除", notes="微信手机号统计信息-通过id删除")
	@RequiresPermissions("linkwechatphonedetectionstatistics:link_wechat_phone_detection_statistics:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		linkWechatPhoneDetectionStatisticsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信手机号统计信息-批量删除")
	@ApiOperation(value="微信手机号统计信息-批量删除", notes="微信手机号统计信息-批量删除")
	@RequiresPermissions("linkwechatphonedetectionstatistics:link_wechat_phone_detection_statistics:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.linkWechatPhoneDetectionStatisticsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信手机号统计信息-通过id查询")
	@ApiOperation(value="微信手机号统计信息-通过id查询", notes="微信手机号统计信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<LinkWechatPhoneDetectionStatistics> queryById(@RequestParam(name="id",required=true) String id) {
		LinkWechatPhoneDetectionStatistics linkWechatPhoneDetectionStatistics = linkWechatPhoneDetectionStatisticsService.getById(id);
		if(linkWechatPhoneDetectionStatistics==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(linkWechatPhoneDetectionStatistics);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param linkWechatPhoneDetectionStatistics
    */
    @RequiresPermissions("linkwechatphonedetectionstatistics:link_wechat_phone_detection_statistics:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, LinkWechatPhoneDetectionStatistics linkWechatPhoneDetectionStatistics) {
        return super.exportXls(request, linkWechatPhoneDetectionStatistics, LinkWechatPhoneDetectionStatistics.class, "微信手机号统计信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("linkwechatphonedetectionstatistics:link_wechat_phone_detection_statistics:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, LinkWechatPhoneDetectionStatistics.class);
    }

}
