import {BasicColumn} from '/@/components/Table';
import {FormSchema} from '/@/components/Table';
import { rules} from '/@/utils/helper/validator';
import { render } from '/@/utils/common/renderUtils';
//列表数据
export const columns: BasicColumn[] = [
  {
    title: '微博用户id',
    align: "center",
    dataIndex: 'userId'
  },
  {
    title: '微博昵称',
    align: "center",
    dataIndex: 'screenName'
  },
  {
    title: '校验类型（扫描/校验）',
    align: "center",
    dataIndex: 'testType_dictText'
  },
  {
    title: '扫描时间',
    align: "center",
    dataIndex: 'scanTime'
  },
  {
    title: '银行卡数量',
    align: "center",
    dataIndex: 'bankCardCount'
  },
];

//查询数据
export const searchFormSchema: FormSchema[] = [
  {
    label: "微博用户id",
    field: 'userId',
    component: 'Input',
    colProps: {span: 6},
  },
  {
    label: "微博昵称",
    field: 'screenName',
    component: 'Input',
    colProps: {span: 6},
  },
  {
    label: "校验类型（扫描/校验）",
    field: 'testType',
    component: 'JDictSelectTag',
    componentProps:{
      dictCode: "scan_test_type"
    },
    colProps: {span: 6},
  },
  {
    label: "扫描时间",
    field: "scanTime",
    component: 'RangePicker',
    componentProps: {
      showTime: true,
    },
    colProps: {span: 6},
  },
  {
    label: "银行卡数量",
    field: 'bankCardCount',
    component: 'Input',
    colProps: {span: 6},
  },
];

//表单数据
export const formSchema: FormSchema[] = [
  {
    label: '微博用户id',
    field: 'userId',
    component: 'Input',
    dynamicRules: ({model,schema}) => {
      return [
              { required: true, message: '请输入微博用户id!'},
             ];
    },
  },
  {
    label: '微博昵称',
    field: 'screenName',
    component: 'Input',
    dynamicRules: ({model,schema}) => {
      return [
              { required: true, message: '请输入微博昵称!'},
             ];
    },
  },
  {
    label: '校验类型（扫描/校验）',
    field: 'testType',
    component: 'JDictSelectTag',
    componentProps:{
      dictCode: "scan_test_type"
    },
    dynamicRules: ({model,schema}) => {
      return [
              { required: true, message: '请输入校验类型（扫描/校验）!'},
             ];
    },
  },
  {
    label: '扫描时间',
    field: 'scanTime',
    component: 'DatePicker',
    componentProps: {
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss'
    },
    dynamicRules: ({model,schema}) => {
      return [
              { required: true, message: '请输入扫描时间!'},
             ];
    },
  },
  {
    label: '银行卡数量',
    field: 'bankCardCount',
    component: 'InputNumber',
    dynamicRules: ({model,schema}) => {
      return [
              { required: true, message: '请输入银行卡数量!'},
             ];
    },
  },
	// TODO 主键隐藏字段，目前写死为ID
  {
    label: '',
    field: 'id',
    component: 'Input',
    show: false,
  },
];
