package org.jeecg.modules.demo.wechatprofiles.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.wechatprofiles.entity.WechatProfiles;
import org.jeecg.modules.demo.wechatprofiles.service.IWechatProfilesService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微信公众号
 * @Author: jeecg-boot
 * @Date:   2023-05-22
 * @Version: V1.0
 */
@Api(tags="微信公众号")
@RestController
@RequestMapping("/wechatprofiles/wechatProfiles")
@Slf4j
public class WechatProfilesController extends JeecgController<WechatProfiles, IWechatProfilesService> {
	@Autowired
	private IWechatProfilesService wechatProfilesService;
	
	/**
	 * 分页列表查询
	 *
	 * @param wechatProfiles
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微信公众号-分页列表查询")
	@ApiOperation(value="微信公众号-分页列表查询", notes="微信公众号-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<WechatProfiles>> queryPageList(WechatProfiles wechatProfiles,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<WechatProfiles> queryWrapper = QueryGenerator.initQueryWrapper(wechatProfiles, req.getParameterMap());
		Page<WechatProfiles> page = new Page<WechatProfiles>(pageNo, pageSize);
		IPage<WechatProfiles> pageList = wechatProfilesService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param wechatProfiles
	 * @return
	 */
	@AutoLog(value = "微信公众号-添加")
	@ApiOperation(value="微信公众号-添加", notes="微信公众号-添加")
	@RequiresPermissions("wechatprofiles:wechat_profiles:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody WechatProfiles wechatProfiles) {
		wechatProfilesService.save(wechatProfiles);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param wechatProfiles
	 * @return
	 */
	@AutoLog(value = "微信公众号-编辑")
	@ApiOperation(value="微信公众号-编辑", notes="微信公众号-编辑")
	@RequiresPermissions("wechatprofiles:wechat_profiles:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody WechatProfiles wechatProfiles) {
		wechatProfilesService.updateById(wechatProfiles);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微信公众号-通过id删除")
	@ApiOperation(value="微信公众号-通过id删除", notes="微信公众号-通过id删除")
	@RequiresPermissions("wechatprofiles:wechat_profiles:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		wechatProfilesService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微信公众号-批量删除")
	@ApiOperation(value="微信公众号-批量删除", notes="微信公众号-批量删除")
	@RequiresPermissions("wechatprofiles:wechat_profiles:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.wechatProfilesService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微信公众号-通过id查询")
	@ApiOperation(value="微信公众号-通过id查询", notes="微信公众号-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<WechatProfiles> queryById(@RequestParam(name="id",required=true) String id) {
		WechatProfiles wechatProfiles = wechatProfilesService.getById(id);
		if(wechatProfiles==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(wechatProfiles);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param wechatProfiles
    */
    @RequiresPermissions("wechatprofiles:wechat_profiles:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, WechatProfiles wechatProfiles) {
        return super.exportXls(request, wechatProfiles, WechatProfiles.class, "微信公众号");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("wechatprofiles:wechat_profiles:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, WechatProfiles.class);
    }

}
