package org.jeecg.modules.demo.weibo.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.weibo.entity.Weibo;
import org.jeecg.modules.demo.weibo.service.IWeiboService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 微博管理
 * @Author: jeecg-boot
 * @Date:   2023-05-08
 * @Version: V1.0
 */
@Api(tags="微博管理")
@RestController
@RequestMapping("/weibo/weibo")
@Slf4j
public class WeiboController extends JeecgController<Weibo, IWeiboService> {
	@Autowired
	private IWeiboService weiboService;
	
	/**
	 * 分页列表查询
	 *
	 * @param weibo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "微博管理-分页列表查询")
	@ApiOperation(value="微博管理-分页列表查询", notes="微博管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<Weibo>> queryPageList(Weibo weibo,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<Weibo> queryWrapper = QueryGenerator.initQueryWrapper(weibo, req.getParameterMap());
		Page<Weibo> page = new Page<Weibo>(pageNo, pageSize);
		IPage<Weibo> pageList = weiboService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param weibo
	 * @return
	 */
	@AutoLog(value = "微博管理-添加")
	@ApiOperation(value="微博管理-添加", notes="微博管理-添加")
	@RequiresPermissions("weibo:weibo:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody Weibo weibo) {
		weiboService.save(weibo);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param weibo
	 * @return
	 */
	@AutoLog(value = "微博管理-编辑")
	@ApiOperation(value="微博管理-编辑", notes="微博管理-编辑")
	@RequiresPermissions("weibo:weibo:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody Weibo weibo) {
		weiboService.updateById(weibo);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "微博管理-通过id删除")
	@ApiOperation(value="微博管理-通过id删除", notes="微博管理-通过id删除")
	@RequiresPermissions("weibo:weibo:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		weiboService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "微博管理-批量删除")
	@ApiOperation(value="微博管理-批量删除", notes="微博管理-批量删除")
	@RequiresPermissions("weibo:weibo:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.weiboService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "微博管理-通过id查询")
	@ApiOperation(value="微博管理-通过id查询", notes="微博管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<Weibo> queryById(@RequestParam(name="id",required=true) String id) {
		Weibo weibo = weiboService.getById(id);
		if(weibo==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(weibo);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param weibo
    */
    @RequiresPermissions("weibo:weibo:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, Weibo weibo) {
        return super.exportXls(request, weibo, Weibo.class, "微博管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("weibo:weibo:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, Weibo.class);
    }

}
